@@ -23,8 +23,8 @@
 /* #undef WITH_GPROF */
 #define WITH_SIMD
 #define WITH_AVX2
-#define WITH_CUPS
-#define WITH_JPEG
+/* #undef WITH_CUPS */
+/* #undef WITH_JPEG */
 /* #undef WITH_WIN8 */
 /* #undef WITH_AAD */
 /* #undef WITH_CAIRO */
@@ -35,7 +35,7 @@
 /* #undef WITH_MACAUDIO */
 /* #undef WITH_OSS */
 #define WITH_ALSA
-#define WITH_PULSE
+/* #undef WITH_PULSE */
 /* #undef WITH_IOSAUDIO */
 /* #undef WITH_OPENSLES */
 /* #undef WITH_GSM */
@@ -62,7 +62,7 @@
 
 #define WITH_CHANNELS
 #define WITH_CLIENT_CHANNELS
-#define WITH_SERVER_CHANNELS
+/* #undef WITH_SERVER_CHANNELS */
 
 /* #undef WITH_CHANNEL_GFXREDIR */
 /* #undef WITH_CHANNEL_RDPAPPLIST */
@@ -120,7 +120,7 @@
 #define CHANNEL_PARALLEL_CLIENT
 /* #undef CHANNEL_PARALLEL_SERVER */
 #define CHANNEL_PRINTER
-#define CHANNEL_PRINTER_CLIENT
+/* #undef CHANNEL_PRINTER_CLIENT */
 /* #undef CHANNEL_PRINTER_SERVER */
 #define CHANNEL_RAIL
 #define CHANNEL_RAIL_CLIENT
@@ -178,8 +178,8 @@
 /* #undef CHANNEL_TSMF */
 /* #undef CHANNEL_TSMF_CLIENT */
 /* #undef CHANNEL_TSMF_SERVER */
-#define CHANNEL_URBDRC
-#define CHANNEL_URBDRC_CLIENT
+/* #undef CHANNEL_URBDRC */
+/* #undef CHANNEL_URBDRC_CLIENT */
 /* #undef CHANNEL_URBDRC_SERVER */
 #define CHANNEL_VIDEO
 #define CHANNEL_VIDEO_CLIENT
@@ -218,7 +218,7 @@
 /* #undef WITH_DEBUG_RINGBUFFER */
 
 /* Proxy */
-#define WITH_PROXY_MODULES
+/* #undef WITH_PROXY_MODULES */
 /* #undef WITH_PROXY_EMULATE_SMARTCARD */
 
 /** If defined linux/vm_sockets.h support is available.
